.. _tutorial:

cerebra Tutorial
=================

Installation
------------

.. toctree::
    :maxdepth: 2

    installation

Beginning examples
------------------

.. toctree::
    :maxdepth: 1

    tutorial/beginning_examples

Advanced examples
-----------------

.. toctree::
    :maxdepth: 1

    tutorial/advanced_examples

Day to day helpful tips and tricks
----------------------------------

.. toctree::
    :maxdepth: 2

    tutorial/tips_and_tricks

Recreated papers
----------------

.. toctree::
    :maxdepth: 1

    tutorial/shalek2013
